@@ -3,6 +3,7 @@ package buffer
 import (
 	"errors"
 	"io"
+	"slices"
 )
 
 type bytesReader struct {
@@ -52,25 +53,14 @@ func (r *bytesReader) ReadAt(b []byte, offset int64) (n int, err error) {
 	return
 }
 
-func (r *bytesReader) replaceByte(offset int64, b byte) {
-	l := int64(len(r.bs))
-	switch {
-	case offset == l:
-		r.bs = append(r.bs, b)
-	case 0 <= offset && offset < l:
-		r.bs[offset] = b
-	default:
-		panic("buffer.bytesReader.replaceByte: unreachable")
-	}
+func (r *bytesReader) insert(offset int64, b byte) {
+	r.bs = slices.Insert(r.bs, int(offset), b)
 }
 
-func (r *bytesReader) deleteByte(offset int64) {
-	copy(r.bs[offset:], r.bs[offset+1:])
-	r.bs = r.bs[:len(r.bs)-1]
+func (r *bytesReader) delete(offset int64) {
+	r.bs = slices.Delete(r.bs, int(offset), int(offset+1))
 }
 
 func (r *bytesReader) clone() *bytesReader {
-	bs := make([]byte, len(r.bs))
-	copy(bs, r.bs)
-	return newBytesReader(bs)
+	return newBytesReader(slices.Clone(r.bs))
 }
